@@ -58,7 +58,7 @@ impl Frontmatter {
 
         if let Some(ref tags) = tags {
             if tags.iter().any(|x| x.trim().is_empty()) {
-                failure::bail!("Empty strings are not allowed in tags");
+                anyhow::bail!("Empty strings are not allowed in tags");
             }
         }
         let tags = if tags.as_ref().map(|t| t.len()).unwrap_or(0) == 0 {
@@ -70,8 +70,8 @@ impl Frontmatter {
             pagination: pagination
                 .and_then(|p| pagination::PaginationConfig::from_config(p, &permalink)),
             permalink,
-            slug: slug.ok_or_else(|| failure::err_msg("No slug"))?,
-            title: title.ok_or_else(|| failure::err_msg("No title"))?,
+            slug: slug.ok_or_else(|| anyhow::format_err!("No slug"))?,
+            title: title.ok_or_else(|| anyhow::format_err!("No title"))?,
             description,
             excerpt,
             categories: categories.unwrap_or_default(),
@@ -92,7 +92,7 @@ impl Frontmatter {
 
         if let Some(pagination) = &fm.pagination {
             if !pagination::is_date_index_sorted(&pagination.date_index) {
-                failure::bail!("date_index is not correctly sorted: Year > Month > Day...");
+                anyhow::bail!("date_index is not correctly sorted: Year > Month > Day...");
             }
         }
         Ok(fm)
